{pkgs', ...}:
pkgs'.writeShellScriptBin "run-tests" ''
  source ${pkgs'.common}/bin/common

  echo_section "run tests"
  echo_hint "This script will run tests in the current working directory."
  echo_hint "The command is executed in the current working directory and not in a nix derivation."
  cd_working_dir

  TEST_PATH="./test"
  TEST_CASES_PATH="''${TEST_PATH}/cases/"

  echo_section "choose the test option"

  selection=$(${pkgs'.gum}/bin/gum choose "run specific test" "run all tests" "Cancel")

  if [[ "$selection" == "Cancel" ]]; then
    echo_ok "You cancelled the operation."
    exit 0
  fi

  if [[ "$selection" == "run all tests" ]]; then
     echo_step "run specific tests"
     if ! ${pkgs'.nodePackages.mocha}/bin/mocha --colors --jobs 1 --bail --recursive $TEST_CASES_PATH
     then
        echo_fail "Tests failed, check your JS!"
        exit 1
     fi
     exit 0
  fi

  escaped_test_cases_path=$(${pkgs'.coreutils}/bin/printf '%s\n' "$TEST_CASES_PATH" | ${pkgs'.gnused}/bin/sed 's:[\\/&]:\\&:g;$!s/$/\\/')

  echo_step "run all tests"
  files=$(${pkgs'.findutils}/bin/find $TEST_CASES_PATH -type f -name "*.mjs")
  relative_files=$(echo "$files" | ${pkgs'.gnused}/bin/sed "s|''${escaped_test_cases_path}||g")

  selected=$(echo "$relative_files" | ${pkgs'.gum}/bin/gum filter --no-limit --header="Select the test case to run" --placeholder="Select test case to run, use tab to select multiple files")

  if [[ -z "$selected" ]]; then
    echo_ok "No test case selected, exiting."
    exit 0
  fi

  full_paths=$(echo "$selected" | ${pkgs'.gnused}/bin/sed "s|^|''${escaped_test_cases_path}|")
  if ! ${pkgs'.nodePackages.mocha}/bin/mocha --colors --jobs 1 --bail --recursive $full_paths
  then
    echo_fail "Tests failed, check your JS!"
    exit 1
  fi

''
